@@ -53,7 +53,15 @@ struct ndis_sg_element {
 struct ndis_sg_list {
 	ULONG nent;
 	ULONG_PTR reserved;
-	struct ndis_sg_element *elements;
+	struct ndis_sg_element elements[];
+};
+
+/* when sending packets, ndiswrapper associates exactly one sg element
+ * in sg list */
+struct wrap_tx_sg_list {
+	ULONG nent;
+	ULONG_PTR reserved;
+	struct ndis_sg_element elements[1];
 };
 
 struct ndis_phy_addr_unit {
@@ -135,7 +143,7 @@ enum ndis_encapsulation {
 #define NDIS_TASK_OFFLOAD_VERSION 1
 
 struct ndis_encapsulation_format {
-	enum ndis_encapsulation encapsulation;
+	enum ndis_encapsulation encap;
 	struct {
 		ULONG fixed_header_size:1;
 		ULONG reserved:31;
@@ -148,7 +156,7 @@ struct ndis_task_offload_header {
 	ULONG size;
 	ULONG reserved;
 	ULONG offset_first_task;
-	struct ndis_encapsulation_format encapsulation_format;
+	struct ndis_encapsulation_format encap_format;
 };
 
 struct ndis_task_offload {
@@ -163,8 +171,8 @@ struct ndis_task_offload {
 struct v4_checksum {
 	union {
 		struct {
-			ULONG ip_supported:1;
-			ULONG tcp_supported:1;
+			ULONG ip_opts:1;
+			ULONG tcp_opts:1;
 			ULONG tcp_csum:1;
 			ULONG udp_csum:1;
 			ULONG ip_csum:1;
@@ -188,6 +196,14 @@ struct ndis_task_tcp_ip_checksum {
 	struct v6_checksum v6_rx;
 };
 
+struct ndis_task_tcp_large_send {
+	ULONG version;
+	ULONG max_size;
+	ULONG min_seg_count;
+	BOOLEAN tcp_opts;
+	BOOLEAN ip_opts;
+};
+
 enum ndis_per_packet_info {
 	TcpIpChecksumPacketInfo, IpSecPacketInfo, TcpLargeSendPacketInfo,
 	ClassificationHandlePacketInfo, NdisReserved,
@@ -212,38 +228,6 @@ struct ndis_packet_private {
 	USHORT oob_offset;
 };
 
-/* OOB data */
-struct ndis_packet_oob_data {
-	union {
-		ULONGLONG time_to_tx;
-		ULONGLONG time_txed;
-	};
-	ULONGLONG time_rxed;
-	UINT header_size;
-	UINT mediaspecific_size;
-	void *mediaspecific;
-	NDIS_STATUS status;
-
-	/* ndiswrapper specific info */
-	struct ndis_packet_extension extension;
-
-	struct ndis_packet *next;
-	struct scatterlist *sg_list;
-	unsigned int sg_ents;
-	struct ndis_sg_list ndis_sg_list;
-	struct ndis_sg_element *ndis_sg_elements;
-	/* RTL8180L overshoots past ndis_eg_elements (during
-	 * MiniportSendPackets) and overwrites what is below, if SG
-	 * DMA is used, so don't use ndis_sg_element in that
-	 * case. This structure is used only when SG is disabled */
-	struct ndis_sg_element ndis_sg_element;
-
-	unsigned char header[ETH_HLEN];
-	unsigned char *look_ahead;
-	UINT look_ahead_size;
-	struct sk_buff *skb;
-};
-
 struct ndis_packet {
 	struct ndis_packet_private private;
 	/* for use by miniport */
@@ -261,11 +245,44 @@ struct ndis_packet {
 		struct {
 			UCHAR mac_reserved[4 * sizeof(void *)];
 		} mac_reserved;
-	} u;
+	};
 	ULONG_PTR reserved[2];
 	UCHAR protocol_reserved[1];
 };
 
+/* OOB data */
+struct ndis_packet_oob_data {
+	union {
+		ULONGLONG time_to_tx;
+		ULONGLONG time_txed;
+	};
+	ULONGLONG time_rxed;
+	UINT header_size;
+	UINT media_size;
+	void *media;
+	NDIS_STATUS status;
+
+	/* ndiswrapper specific info; extension should be right after
+	 * ndis's oob_data */
+	struct ndis_packet_extension ext;
+	union {
+		/* used for tx only */
+		struct {
+			struct sk_buff *tx_skb;
+			union {
+				struct wrap_tx_sg_list wrap_tx_sg_list;
+				struct ndis_sg_list *tx_sg_list;
+			};
+		};
+		/* used for rx only */
+		struct {
+			unsigned char header[ETH_HLEN];
+			unsigned char *look_ahead;
+			UINT look_ahead_size;
+		};
+	};
+};
+
 #define NDIS_PACKET_OOB_DATA(packet)					\
 	(struct ndis_packet_oob_data *)(((void *)(packet)) +		\
 					(packet)->private.oob_offset)
@@ -439,7 +456,7 @@ struct ndis_spinlock {
 };
 
 union ndis_rw_lock_refcount {
-	UINT ref_count;
+	UINT count;
 	UCHAR cache_line[16];
 };
 
@@ -448,10 +465,19 @@ struct ndis_rw_lock {
 		struct {
 			NT_SPIN_LOCK klock;
 			void *context;
-		} s;
+		};
 		UCHAR reserved[16];
-	} u;
-	union ndis_rw_lock_refcount ref_count[MAXIMUM_PROCESSORS];
+	};
+	union {
+		union ndis_rw_lock_refcount ref_count[MAXIMUM_PROCESSORS];
+		/* ndiswrapper specific */
+		int count;
+	};
+};
+
+struct lock_state {
+	USHORT state;
+	KIRQL irql;
 };
 
 struct ndis_work_item;
@@ -846,7 +872,7 @@ struct wrap_ndis_device {
 	NDIS_STATUS ndis_comm_status;
 	ULONG packet_filter;
 
-	BOOLEAN use_sg_dma;
+	ULONG sg_dma_size;
 	ULONG dma_map_count;
 	dma_addr_t *dma_map_addr;
 
@@ -879,7 +905,7 @@ struct wrap_ndis_device {
 	struct ndis_buffer_pool *tx_buffer_pool;
 	int multicast_size;
 	struct v4_checksum rx_csum;
-	struct ndis_tcp_ip_checksum_packet_info tx_csum_info;
+	struct v4_checksum tx_csum;
 	enum ndis_physical_medium physical_medium;
 	u32 ndis_wolopts;
 	struct nt_list timer_list;
