@@ -348,12 +348,6 @@ typedef u32 pm_message_t;
 #define pci_choose_state(dev, state) (state)
 #endif
 
-#if defined(CONFIG_SOFTWARE_SUSPEND2) || defined(CONFIG_SUSPEND2)
-#define KTHREAD_RUN(a,b,c) kthread_run(a,b,0,c)
-#else
-#define KTHREAD_RUN(a,b,c) kthread_run(a,b,c)
-#endif
-
 #if !defined(HAVE_NETDEV_PRIV)
 #define netdev_priv(dev)  ((dev)->priv)
 #endif
@@ -370,6 +364,14 @@ typedef u32 pm_message_t;
 #define flush_icache_range(start, end) do { } while (0)
 #endif
 
+#ifndef CHECKSUM_PARTIAL
+#define CHECKSUM_PARTIAL CHECKSUM_HW
+#endif
+
+#ifndef IRQF_SHARED
+#define IRQF_SHARED SA_SHIRQ
+#endif
+
 #define memcpy_skb(skb, from, length)			\
 	memcpy(skb_put(skb, length), from, length)
 
@@ -388,7 +390,7 @@ typedef u32 pm_message_t;
 #define print_sp() do {				\
 		void *sp;			\
 		get_sp(sp);			\
-		DBGTRACE1("sp: %p", sp);	\
+		TRACE1("sp: %p", sp);	\
 	} while (0)
 
 //#define DEBUG_IRQL 1
@@ -516,6 +518,8 @@ struct wrap_driver {
 	unsigned short num_bin_files;
 	struct wrap_bin_file *bin_files;
 	struct nt_list wrap_devices;
+	struct nt_list settings;
+	int dev_type;
 	struct wrap_ndis_driver *ndis_driver;
 };
 
@@ -777,14 +781,30 @@ void adjust_user_shared_data_addr(char *driver, unsigned long length);
 #define IoCompleteRequest(irp, prio) IofCompleteRequest(irp, prio)
 #define IoCallDriver(dev, irp) IofCallDriver(dev, irp)
 
+#if defined(IO_DEBUG)
+#define DUMP_IRP(irp)							\
+do {									\
+	struct io_stack_location *irp_sl;				\
+	irp_sl = IoGetCurrentIrpStackLocation(irp);			\
+	IOTRACE("irp: %p, stack size: %d, cl: %d, sl: %p, dev_obj: %p, " \
+		"mj_fn: %d, minor_fn: %d, nt_urb: %p, event: %p",	\
+		irp, irp->stack_count, (irp)->current_location,		\
+		irp_sl, irp_sl->dev_obj, irp_sl->major_fn,		\
+		irp_sl->minor_fn, IRP_URB(irp),				\
+		(irp)->user_event);					\
+} while (0)
+#else
+#define DUMP_IRP(irp) do { } while (0)
+#endif
+
 static inline KIRQL current_irql(void)
 {
 	if (in_irq() || irqs_disabled())
-		TRACEEXIT6(return DEVICE_LEVEL);
+		EXIT6(return DEVICE_LEVEL);
 	else if (in_interrupt())
-		TRACEEXIT6(return DISPATCH_LEVEL);
+		EXIT6(return DISPATCH_LEVEL);
 	else
-		TRACEEXIT6(return PASSIVE_LEVEL);
+		EXIT6(return PASSIVE_LEVEL);
 }
 
 static inline KIRQL raise_irql(KIRQL newirql)
@@ -795,14 +815,14 @@ static inline KIRQL raise_irql(KIRQL newirql)
 		local_bh_disable();
 		preempt_disable();
 	}
-	DBGTRACE6("%d, %d", irql, newirql);
+	TRACE6("%d, %d", irql, newirql);
 	return irql;
 }
 
 static inline void lower_irql(KIRQL oldirql)
 {
 	KIRQL irql = current_irql();
-	DBGTRACE6("%d, %d", irql, oldirql);
+	TRACE6("%d, %d", irql, oldirql);
 	DBG_BLOCK(2) {
 		if (irql < oldirql)
 			ERROR("invalid irql: %d < %d", irql, oldirql);
@@ -901,28 +921,24 @@ do {									\
 	preempt_enable();						\
 } while (0)
 
-#define atomic_unary_op(var, size, oper)			\
-do {								\
-	if (size == 1)						\
-		__asm__ __volatile__(				\
-			LOCK_PREFIX oper "b %b0\n\t"		\
-			: "+m" (var));				\
-	else if (size == 2)					\
-		__asm__ __volatile__(				\
-			LOCK_PREFIX oper "w %w0\n\t"		\
-			: "+m" (var));				\
-	else if (size == 4)					\
-		__asm__ __volatile__(				\
-			LOCK_PREFIX oper "l %0\n\t"		\
-			: "+m" (var));				\
-	else if (size == 8)					\
-		__asm__ __volatile__(				\
-			LOCK_PREFIX oper "q %q0\n\t"		\
-			: "+m" (var));				\
-	else {							\
-		extern void _invalid_op_size_(void);		\
-		_invalid_op_size_();				\
-	}							\
+#define atomic_unary_op(var, size, oper)				\
+do {									\
+	if (size == 1)							\
+		__asm__ __volatile__(					\
+			LOCK_PREFIX oper "b %b0\n\t" : "+m" (var));	\
+	else if (size == 2)						\
+		__asm__ __volatile__(					\
+			LOCK_PREFIX oper "w %w0\n\t" : "+m" (var));	\
+	else if (size == 4)						\
+		__asm__ __volatile__(					\
+			LOCK_PREFIX oper "l %0\n\t" : "+m" (var));	\
+	else if (size == 8)						\
+		__asm__ __volatile__(					\
+			LOCK_PREFIX oper "q %q0\n\t" : "+m" (var));	\
+	else {								\
+		extern void _invalid_op_size_(void);			\
+		_invalid_op_size_();					\
+	}								\
 } while (0)
 
 #define atomic_inc_var_size(var, size) atomic_unary_op(var, size, "inc")
@@ -947,8 +963,8 @@ do {								\
 
 #define atomic_insert_list_head(oldhead, head, newhead)			\
 	do {								\
-		oldhead = head;						\
-	} while (cmpxchg(&(head), oldhead, newhead) != oldhead)
+		oldhead = (typeof(oldhead))head;			\
+	} while (cmpxchg(&(head), oldhead, newhead) != (typeof(head))oldhead)
 
 #define atomic_remove_list_head(head, newhead)				\
 ({									\
@@ -990,7 +1006,7 @@ static inline struct nt_slist *PushEntrySList(nt_slist_header *head,
 	head->next = entry;
 	head->depth++;
 	nt_spin_unlock_irql(lock, irql);
-	DBGTRACE4("%p, %p, %p", head, entry, entry->next);
+	TRACE4("%p, %p, %p", head, entry, entry->next);
 	return entry->next;
 }
 
@@ -1005,7 +1021,7 @@ static inline struct nt_slist *PopEntrySList(nt_slist_header *head,
 		head->depth--;
 	}
 	nt_spin_unlock_irql(lock, irql);
-	DBGTRACE4("%p, %p", head, entry);
+	TRACE4("%p, %p", head, entry);
 	return entry;
 }
 
@@ -1040,7 +1056,7 @@ static inline struct nt_slist *PushEntrySList(nt_slist_header *head,
 		new.next = entry;
 		new.depth = old.depth + 1;
 	} while (cmpxchg8b(&head->align, old.align, new.align) != old.align);
-	DBGTRACE4("%p, %p, %p", head, entry, old.next);
+	TRACE4("%p, %p, %p", head, entry, old.next);
 	return old.next;
 }
 
@@ -1057,7 +1073,7 @@ static inline struct nt_slist *PopEntrySList(nt_slist_header *head,
 		new.next = entry->next;
 		new.depth = old.depth - 1;
 	} while (cmpxchg8b(&head->align, old.align, new.align) != old.align);
-	DBGTRACE4("%p, %p", head, entry);
+	TRACE4("%p, %p", head, entry);
 	return entry;
 }
 
