@@ -61,7 +61,7 @@ wstdcall BOOLEAN WIN_FUNC(IoIs32bitProcess,1)
 wstdcall void WIN_FUNC(IoInitializeIrp,3)
 	(struct irp *irp, USHORT size, CCHAR stack_count)
 {
-	IOENTER("irp: %p, count: %d", irp, stack_count);
+	IOENTER("irp: %p, %d, %d", irp, size, stack_count);
 
 	memset(irp, 0, size);
 	irp->size = size;
@@ -96,10 +96,9 @@ wstdcall struct irp *WIN_FUNC(IoAllocateIrp,2)
 	stack_count++;
 	irp_size = IoSizeOfIrp(stack_count);
 	irp = kmalloc(irp_size, gfp_irql());
-	if (irp) {
-		IOTRACE("allocated irp %p", irp);
+	if (irp)
 		IoInitializeIrp(irp, irp_size, stack_count);
-	}
+	IOTRACE("irp %p", irp);
 	IOEXIT(return irp);
 }
 
@@ -343,21 +342,20 @@ wfastcall NTSTATUS WIN_FUNC(IofCallDriver,2)
 	driver_dispatch_t *major_func;
 	struct driver_object *drv_obj;
 
-	IoSetNextIrpStackLocation(irp);
-	DUMP_IRP(irp);
-#ifdef IO_DEBUG
-	if (irp->current_location < 0) {
+	IOTRACE("%p, %p, %p, %d, %d, %p", dev_obj, irp, dev_obj->drv_obj,
+		irp->current_location, irp->stack_count,
+		IoGetCurrentIrpStackLocation(irp));
+	if (irp->current_location <= 0) {
 		ERROR("invalid irp: %p, %d", irp, irp->current_location);
 		return STATUS_INVALID_PARAMETER;
 	}
-#endif
+	IoSetNextIrpStackLocation(irp);
+	DUMP_IRP(irp);
 	irp_sl = IoGetCurrentIrpStackLocation(irp);
 	drv_obj = dev_obj->drv_obj;
 	irp_sl->dev_obj = dev_obj;
-	IOTRACE("drv_obj: %p", drv_obj);
 	major_func = drv_obj->major_func[irp_sl->major_fn];
 	IOTRACE("major_func: %p, dev_obj: %p", major_func, dev_obj);
-	/* TODO: Linux functions must be called natively */
 	if (major_func)
 		status = LIN2WIN2(major_func, dev_obj, irp);
 	else {
@@ -371,6 +369,7 @@ wfastcall NTSTATUS WIN_FUNC(IofCallDriver,2)
 wfastcall void WIN_FUNC(IofCompleteRequest,2)
 	(struct irp *irp, CHAR prio_boost)
 {
+
 #ifdef IO_DEBUG
 	DUMP_IRP(irp);
 	if (irp->io_status.status == STATUS_PENDING) {
@@ -388,6 +387,7 @@ wfastcall void WIN_FUNC(IofCompleteRequest,2)
 		NTSTATUS status;
 
 		irp_sl = IoGetCurrentIrpStackLocation(irp);
+		DUMP_IRP(irp);
 		if (irp_sl->control & SL_PENDING_RETURNED)
 			irp->pending_returned = TRUE;
 
@@ -397,7 +397,7 @@ wfastcall void WIN_FUNC(IofCompleteRequest,2)
 		 * is what we are going to call below; so we set
 		 * current_location and dev_obj for the previous
 		 * (higher) location */
-		DUMP_IRP(irp);
+
 		IoSkipCurrentIrpStackLocation(irp);
 		if (irp->current_location < irp->stack_count)
 			dev_obj = IoGetCurrentIrpStackLocation(irp)->dev_obj;
@@ -408,11 +408,11 @@ wfastcall void WIN_FUNC(IofCompleteRequest,2)
 			dev_obj);
 		if (irp_sl->completion_routine &&
 		    ((irp->io_status.status == STATUS_SUCCESS &&
-		       irp_sl->control & SL_INVOKE_ON_SUCCESS) ||
-		      (irp->io_status.status != STATUS_SUCCESS &&
-		       irp_sl->control & SL_INVOKE_ON_ERROR) ||
-		      (irp->cancel == TRUE &&
-		       irp_sl->control & SL_INVOKE_ON_CANCEL))) {
+		      irp_sl->control & SL_INVOKE_ON_SUCCESS) ||
+		     (irp->io_status.status != STATUS_SUCCESS &&
+		      irp_sl->control & SL_INVOKE_ON_ERROR) ||
+		     (irp->cancel == TRUE &&
+		      irp_sl->control & SL_INVOKE_ON_CANCEL))) {
 			IOTRACE("calling completion_routine at: %p, %p",
 				irp_sl->completion_routine, irp_sl->context);
 			status = LIN2WIN3(irp_sl->completion_routine,
@@ -493,7 +493,7 @@ wstdcall NTSTATUS IoSyncForwardIrp(struct device_object *dev_obj,
 WIN_FUNC_DECL(IoSyncForwardIrp,2)
 
 wstdcall NTSTATUS IoAsyncForwardIrp(struct device_object *dev_obj,
-				   struct irp *irp)
+				    struct irp *irp)
 {
 	NTSTATUS status;
 
@@ -504,7 +504,7 @@ wstdcall NTSTATUS IoAsyncForwardIrp(struct device_object *dev_obj,
 WIN_FUNC_DECL(IoAsyncForwardIrp,2)
 
 wstdcall NTSTATUS IoInvalidDeviceRequest(struct device_object *dev_obj,
-					struct irp *irp)
+					 struct irp *irp)
 {
 	struct io_stack_location *irp_sl;
 	NTSTATUS status;
@@ -560,7 +560,7 @@ wstdcall NTSTATUS WIN_FUNC(IoConnectInterrupt,11)
 	InitializeListHead(&interrupt->list);
 	interrupt->synch_irql = synch_irql;
 	interrupt->interrupt_mode = interrupt_mode;
-	if (request_irq(vector, io_irq_isr, shareable ? SA_SHIRQ : 0,
+	if (request_irq(vector, io_irq_isr, shareable ? IRQF_SHARED : 0,
 			"io_irq", interrupt)) {
 		WARNING("request for irq %d failed", vector);
 		IOEXIT(return STATUS_INSUFFICIENT_RESOURCES);
@@ -812,22 +812,22 @@ wstdcall void WIN_FUNC(IoDeleteDevice,1)
 }
 
 wstdcall void WIN_FUNC(IoDetachDevice,1)
-	(struct device_object *topdev)
+	(struct device_object *tgt)
 {
 	struct device_object *tail;
 	KIRQL irql;
 
-	IOENTER("%p", topdev);
-	if (!topdev)
+	IOENTER("%p", tgt);
+	if (!tgt)
 		IOEXIT(return);
-	tail = topdev->attached;
+	tail = tgt->attached;
 	if (!tail)
 		IOEXIT(return);
 	IOTRACE("tail: %p", tail);
 
 	irql = nt_spin_lock_irql(&ntoskernel_lock, DISPATCH_LEVEL);
-	topdev->attached = tail->attached;
-	IOTRACE("attached:%p", topdev->attached);
+	tgt->attached = tail->attached;
+	IOTRACE("attached:%p", tgt->attached);
 	for ( ; tail; tail = tail->attached) {
 		IOTRACE("tail:%p", tail);
 		tail->stack_count--;
@@ -839,31 +839,27 @@ wstdcall void WIN_FUNC(IoDetachDevice,1)
 wstdcall struct device_object *WIN_FUNC(IoGetAttachedDevice,1)
 	(struct device_object *dev)
 {
-	struct device_object *top_dev;
 	KIRQL irql;
 
 	IOENTER("%p", dev);
 	if (!dev)
 		IOEXIT(return NULL);
 	irql = nt_spin_lock_irql(&ntoskernel_lock, DISPATCH_LEVEL);
-	top_dev = dev;
-	while (top_dev->attached)
-		top_dev = top_dev->attached;
+	while (dev->attached)
+		dev = dev->attached;
 	nt_spin_unlock_irql(&ntoskernel_lock, irql);
-	IOEXIT(return top_dev);
+	IOEXIT(return dev);
 }
 
 wstdcall struct device_object *WIN_FUNC(IoGetAttachedDeviceReference,1)
 	(struct device_object *dev)
 {
-	struct device_object *top_dev;
-
 	IOENTER("%p", dev);
 	if (!dev)
 		IOEXIT(return NULL);
-	top_dev = IoGetAttachedDevice(dev);
-	ObReferenceObject(top_dev);
-	IOEXIT(return top_dev);
+	dev = IoGetAttachedDevice(dev);
+	ObReferenceObject(dev);
+	IOEXIT(return dev);
 }
 
 wstdcall struct device_object *WIN_FUNC(IoAttachDeviceToDeviceStack,2)
@@ -943,12 +939,12 @@ wstdcall NTSTATUS WIN_FUNC(IoGetDeviceObjectPointer,4)
 	file_obj = NULL;
 	irql = nt_spin_lock_irql(&ntoskernel_lock, DISPATCH_LEVEL);
 	nt_list_for_each_entry(coh, &object_list, list) {
-		DBGTRACE5("header: %p, type: %d", coh, coh->type);
+		TRACE5("header: %p, type: %d", coh, coh->type);
 		if (coh->type != OBJECT_TYPE_DEVICE)
 			continue;
 		if (!RtlCompareUnicodeString(&coh->name, name, TRUE)) {
 			dev_obj = HEADER_TO_OBJECT(coh);
-			DBGTRACE5("dev_obj: %p", dev_obj);
+			TRACE5("dev_obj: %p", dev_obj);
 			break;
 		}
 	}
@@ -982,8 +978,7 @@ wstdcall NTSTATUS WIN_FUNC(PoRequestPowerIrp,6)
 	struct irp *irp;
 	struct io_stack_location *irp_sl;
 
-	DBGTRACE1("%p: stack size: %d", dev_obj, dev_obj->stack_count);
-	DBGTRACE1("drv_obj: %p", dev_obj->drv_obj);
+	TRACE1("%p, %d, %p", dev_obj, dev_obj->stack_count, dev_obj->drv_obj);
 	irp = IoAllocateIrp(dev_obj->stack_count, FALSE);
 	if (!irp)
 		return STATUS_INSUFFICIENT_RESOURCES;
@@ -1021,7 +1016,7 @@ wstdcall void *WIN_FUNC(IoAllocateErrorLogEntry,2)
 	/* not implemented fully */
 	void *ret = kmalloc(sizeof(struct io_error_log_packet) + entry_size,
 			    gfp_irql());
-	DBGTRACE2("%p", ret);
+	TRACE2("%p", ret);
 	if (ret)
 		return ret + sizeof(struct io_error_log_packet);
 	else
@@ -1038,7 +1033,7 @@ wstdcall void WIN_FUNC(IoWriteErrorLogEntry,1)
 wstdcall void WIN_FUNC(IoFreeErrorLogEntry,1)
 	(void *entry)
 {
-	DBGTRACE2("%p", entry);
+	TRACE2("%p", entry);
 	kfree(entry - sizeof(struct io_error_log_packet));
 }
 
@@ -1065,16 +1060,15 @@ wstdcall NTSTATUS WIN_FUNC(IoRegisterDeviceInterface,4)
 
 	/* TODO: check if pdo is valid */
 	RtlInitAnsiString(&ansi, "ndis");
-	TRACEENTER1("pdo: %p, ref: %p, link: %p, %x, %x, %x",
-		    pdo, reference, link, guid_class->data1,
-		    guid_class->data2, guid_class->data3);
+	ENTER1("pdo: %p, ref: %p, link: %p, %x, %x, %x", pdo, reference, link,
+	       guid_class->data1, guid_class->data2, guid_class->data3);
 	return RtlAnsiStringToUnicodeString(link, &ansi, TRUE);
 }
 
 wstdcall NTSTATUS WIN_FUNC(IoSetDeviceInterfaceState,2)
 	(struct unicode_string *link, BOOLEAN enable)
 {
-	TRACEENTER1("link: %p, enable: %d", link, enable);
+	ENTER1("link: %p, enable: %d", link, enable);
 	return STATUS_SUCCESS;
 }
 
@@ -1082,7 +1076,7 @@ wstdcall NTSTATUS WIN_FUNC(IoOpenDeviceRegistryKey,4)
 	(struct device_object *dev_obj, ULONG type, ACCESS_MASK mask,
 	 void **handle)
 {
-	TRACEENTER1("dev_obj: %p", dev_obj);
+	ENTER1("dev_obj: %p", dev_obj);
 	*handle = dev_obj;
 	return STATUS_SUCCESS;
 }
@@ -1090,8 +1084,8 @@ wstdcall NTSTATUS WIN_FUNC(IoOpenDeviceRegistryKey,4)
 wstdcall NTSTATUS WIN_FUNC(IoWMIRegistrationControl,2)
 	(struct device_object *dev_obj, ULONG action)
 {
-	TRACEENTER2("%p, %d", dev_obj, action);
-	TRACEEXIT2(return STATUS_SUCCESS);
+	ENTER2("%p, %d", dev_obj, action);
+	EXIT2(return STATUS_SUCCESS);
 }
 
 wstdcall void WIN_FUNC(IoInvalidateDeviceRelations,2)
