@@ -45,6 +45,7 @@
 #define STATUS_NO_MEMORY		0xC0000017
 #define STATUS_CANCELLED                0xC0000120
 #define STATUS_DEVICE_REMOVED		0xC00002B6
+#define STATUS_DEVICE_NOT_CONNECTED	0xC000009D
 
 #define STATUS_BUFFER_OVERFLOW		0x80000005
 
@@ -327,7 +328,7 @@ do {									\
 	(mdl)->byteoffset = BYTE_OFFSET(baseva);			\
 	(mdl)->bytecount = length;					\
 	(mdl)->mappedsystemva = baseva;					\
-	DBGTRACE4("%p %p %p %d %d", (mdl), baseva, (mdl)->startva,	\
+	TRACE4("%p %p %p %d %d", (mdl), baseva, (mdl)->startva,	\
 		  (mdl)->byteoffset, length);				\
 } while (0)
 
@@ -960,9 +961,6 @@ struct io_stack_location {
 #pragma pack(pop)
 #endif
 
-#define URB_FROM_IRP(irp)						\
-	(union nt_urb *)(IoGetCurrentIrpStackLocation(irp)->params.others.arg1)
-
 struct kapc {
 	CSHORT type;
 	CSHORT size;
@@ -1047,27 +1045,30 @@ struct irp {
 			struct {
 				struct nt_list list;
 				union {
-					struct io_stack_location *
-					current_stack_location;
+					struct io_stack_location *csl;
 					ULONG packet_type;
 				};
 			};
 			struct file_object *file_object;
 		} overlay;
-		struct kapc apc;
+		union {
+			struct kapc apc;
+			/* space for apc is used for ndiswrapper
+			 * specific fields */
+			struct {
+				struct wrap_urb *wrap_urb;
+				struct wrap_device *wrap_device;
+			};
+		};
 		void *completion_key;
 	} tail;
-
-	/* ndiswrapper extension */
-	struct wrap_urb *wrap_urb;
-	struct wrap_device *wd;
 };
 
 #define IoSizeOfIrp(stack_count)					\
 	((USHORT)(sizeof(struct irp) + ((stack_count) *			\
 					sizeof(struct io_stack_location))))
 #define IoGetCurrentIrpStackLocation(irp)		\
-	(irp)->tail.overlay.current_stack_location
+	(irp)->tail.overlay.csl
 #define IoGetNextIrpStackLocation(irp)		\
 	(IoGetCurrentIrpStackLocation(irp) - 1)
 #define IoGetPreviousIrpStackLocation(irp)	\
@@ -1116,10 +1117,16 @@ IoSetCompletionRoutine(struct irp *irp, void *routine, void *context,
 #define IoUnmarkIrpPending(irp)						\
 	(IoGetCurrentIrpStackLocation((irp))->control &= ~SL_PENDING_RETURNED)
 
-#define IRP_SL(irp, i) (((struct io_stack_location *)((irp) + 1)) + (i))
+#define IRP_SL(irp, n) (((struct io_stack_location *)((irp) + 1)) + (n))
 #define IRP_DRIVER_CONTEXT(irp) (irp)->tail.overlay.driver_context
 #define IoIrpThread(irp) ((irp)->tail.overlay.thread)
 
+#define IRP_URB(irp)							\
+	(union nt_urb *)(IoGetCurrentIrpStackLocation(irp)->params.others.arg1)
+
+#define IRP_WRAP_DEVICE(irp) (irp)->tail.wrap_device
+#define IRP_WRAP_URB(irp) (irp)->tail.wrap_urb
+
 struct wmi_guid_reg_info {
 	struct guid *guid;
 	ULONG instance_count;
